@@ -9,8 +9,8 @@ print.empca <- function(x, ncomp = x$impute.ncomps, ...) {
     graph.cvs <- with(df, ggplot(df, aes_string(as.factor(pca.ncomp), value)) + 
       theme_bw() + 
       theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
-      geom_point(aes_string(col = variable), size = 5) + 
-      geom_line(aes_string(col = variable, group = variable), lwd = 1.25) + 
+      geom_point(aes_string(pch = variable), size = 5) + 
+      geom_line(aes_string(lty = variable, group = variable), lwd = 1.25) + 
       ylab("GVC MSEP Approximation") + 
       xlab("PCA on Imputed Dataframe\nwith this No. of PCs") + 
       theme(axis.text.x = element_text(angle = 90, hjust = 1)) +
